var group__spa__node =
[
    [ "command.h", "node_2command_8h.html", null ],
    [ "event.h", "node_2event_8h.html", null ],
    [ "io.h", "io_8h.html", null ],
    [ "keys.h", "spa_2include_2spa_2node_2keys_8h.html", null ],
    [ "node.h", "spa_2include_2spa_2node_2node_8h.html", null ],
    [ "type-info.h", "node_2type-info_8h.html", null ],
    [ "spa_io_buffers", "structspa__io__buffers.html", [
      [ "status", "structspa__io__buffers.html#a1364df7bc201533525e5a4fa54f444fe", null ],
      [ "buffer_id", "structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b", null ]
    ] ],
    [ "spa_io_memory", "structspa__io__memory.html", [
      [ "status", "structspa__io__memory.html#a25a75f4edf0631a335b0dfd55c214f3e", null ],
      [ "size", "structspa__io__memory.html#af7c688ea663d461d5c880d0629c7fa49", null ],
      [ "data", "structspa__io__memory.html#a8ad18bb75b7dda83388267077331068c", null ]
    ] ],
    [ "spa_io_range", "structspa__io__range.html", [
      [ "offset", "structspa__io__range.html#a2a824a298a2e459bb719ed29f57de141", null ],
      [ "min_size", "structspa__io__range.html#af3d7c25e34fd60458e8ca8cfa1067c92", null ],
      [ "max_size", "structspa__io__range.html#adac0f561e72d269206216a3327720ff7", null ]
    ] ],
    [ "spa_io_clock", "structspa__io__clock.html", [
      [ "flags", "structspa__io__clock.html#ab3d44cc4e16a47abd913553c3b977051", null ],
      [ "id", "structspa__io__clock.html#ab639d1a64a22eecfa76ca04001bc163d", null ],
      [ "nsec", "structspa__io__clock.html#a726264b491673c896b53038752149ecb", null ],
      [ "rate", "structspa__io__clock.html#a96d1fa8bd97bb1a840403a103853673e", null ],
      [ "position", "structspa__io__clock.html#a4813e6c9101d56eb1f3ac2e9eda1d8c8", null ],
      [ "duration", "structspa__io__clock.html#af384237834c65792f29ccfd3fadfeefe", null ],
      [ "delay", "structspa__io__clock.html#af8fa38eef9a514c13306bd01da06e776", null ],
      [ "rate_diff", "structspa__io__clock.html#aaddd01ce3e78da42c39efdeab2180035", null ],
      [ "next_nsec", "structspa__io__clock.html#a3242b88552347adc2e406b75f8136060", null ],
      [ "target_rate", "structspa__io__clock.html#a02274245ac560717fc5c06ddc66553ff", null ],
      [ "target_duration", "structspa__io__clock.html#ad5f6c0254efd87a20ca5807b577d3473", null ],
      [ "target_seq", "structspa__io__clock.html#af91526e984d8c9453e8b98c12dd1f500", null ],
      [ "padding", "structspa__io__clock.html#add07660ad1ad6f6951596c5a0422cd9b", null ],
      [ "xrun", "structspa__io__clock.html#a3dc77892eea443b66c01d2acc91acaeb", null ]
    ] ],
    [ "spa_io_video_size", "structspa__io__video__size.html", [
      [ "flags", "structspa__io__video__size.html#ab8f1361af870dd5de789b63b687a22ce", null ],
      [ "stride", "structspa__io__video__size.html#a817931821ee7f154884141faa47647c0", null ],
      [ "size", "structspa__io__video__size.html#ac21892f7b4b6c90063b80306659a657b", null ],
      [ "framerate", "structspa__io__video__size.html#a14c82d8b6ae358c42c68f7dba2666b18", null ],
      [ "padding", "structspa__io__video__size.html#a259e1fe5e8894a35cf6849b94059ac7f", null ]
    ] ],
    [ "spa_io_latency", "structspa__io__latency.html", [
      [ "rate", "structspa__io__latency.html#aebb31ddb5622017843ee612c7c66f32a", null ],
      [ "min", "structspa__io__latency.html#a017f13089f0f6847cd70e62d725bd99c", null ],
      [ "max", "structspa__io__latency.html#a5f23744c90a1dc0e9f0c1e067b8d390a", null ]
    ] ],
    [ "spa_io_sequence", "structspa__io__sequence.html", [
      [ "sequence", "structspa__io__sequence.html#ab6a424dad012da97efc02bfa77ed57d9", null ]
    ] ],
    [ "spa_io_segment_bar", "structspa__io__segment__bar.html", [
      [ "flags", "structspa__io__segment__bar.html#afaad39c0e35dbd2e4fc075a93914341f", null ],
      [ "offset", "structspa__io__segment__bar.html#ad6d079e00b9b7428ab66c7f7fc5e0a5e", null ],
      [ "signature_num", "structspa__io__segment__bar.html#af6cb2a9476c6fda23897ed5d45b3f2d4", null ],
      [ "signature_denom", "structspa__io__segment__bar.html#a65f1a61b7161bc2ddfb12e2bec1c51d3", null ],
      [ "bpm", "structspa__io__segment__bar.html#a5398027b6c636c287b2df47239b6b9e3", null ],
      [ "beat", "structspa__io__segment__bar.html#a212f71e2e8b5587d48f4a71151ebdda5", null ],
      [ "padding", "structspa__io__segment__bar.html#a23933e48afa26296c4b2c2df6470bb12", null ]
    ] ],
    [ "spa_io_segment_video", "structspa__io__segment__video.html", [
      [ "flags", "structspa__io__segment__video.html#abb72f2853693bb3cfad27520b41f3248", null ],
      [ "offset", "structspa__io__segment__video.html#aefffdac704f6aa878542c37d5cc7accb", null ],
      [ "framerate", "structspa__io__segment__video.html#a500d2d64d490ad483be879cb40b799b4", null ],
      [ "hours", "structspa__io__segment__video.html#ad9a1cecce33ac8e1c02532188fe51b5f", null ],
      [ "minutes", "structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db", null ],
      [ "seconds", "structspa__io__segment__video.html#a4f9acf42fec13d66072ac47ca9aad116", null ],
      [ "frames", "structspa__io__segment__video.html#ae1cc1d15b524665254cff4c3d5daeceb", null ],
      [ "field_count", "structspa__io__segment__video.html#a9c45645d7e6aa9aea4508336dd87d17d", null ],
      [ "padding", "structspa__io__segment__video.html#ae03652e1ab2e76a1a03a63d7bd0fcc99", null ]
    ] ],
    [ "spa_io_segment", "structspa__io__segment.html", [
      [ "version", "structspa__io__segment.html#af9ec3a1565e77b1ad781376b758b58c3", null ],
      [ "flags", "structspa__io__segment.html#a6ba7bf8b5ba9725546b59b1918f49cc7", null ],
      [ "duration", "structspa__io__segment.html#a6b7f7b35362210bbb0548ce4ab463e12", null ],
      [ "rate", "structspa__io__segment.html#ab725d4cd7f8cb1a44abe185ac504fd1c", null ],
      [ "position", "structspa__io__segment.html#aa0c906a4de1d90ec5042826b14742301", null ],
      [ "bar", "structspa__io__segment.html#ad525d9a6f0185e329abc7e89fe394cfd", null ],
      [ "video", "structspa__io__segment.html#ac4988f1d377a80a859eb45771f3317fb", null ]
    ] ],
    [ "spa_io_position", "structspa__io__position.html", [
      [ "clock", "structspa__io__position.html#a0e69b290ceddaa228852e517d67a8ff8", null ],
      [ "video", "structspa__io__position.html#a112b0de264eccfba2c44c9a4a917b83d", null ],
      [ "offset", "structspa__io__position.html#afa5a197f2a03c7b71ed7d99bcd3a3718", null ],
      [ "state", "structspa__io__position.html#a576f55a0a4a9b468cedb3c4ccb41a0c4", null ],
      [ "n_segments", "structspa__io__position.html#a6381154ac49e6f6f37c2a7d65366b7b8", null ],
      [ "segments", "structspa__io__position.html#a6b6da4b94ab7924dda2007712ff2e8f1", null ]
    ] ],
    [ "spa_io_rate_match", "structspa__io__rate__match.html", [
      [ "delay", "structspa__io__rate__match.html#a9d0be859f40cffcebe7b829d19fcacee", null ],
      [ "size", "structspa__io__rate__match.html#ad8a395240a4b89d6be0e67538cf6ad5c", null ],
      [ "rate", "structspa__io__rate__match.html#a8f9575e69576c942758927acba7daeef", null ],
      [ "flags", "structspa__io__rate__match.html#a7b89f4c442e2856faf64abeec186050e", null ],
      [ "padding", "structspa__io__rate__match.html#a2ef8495597b9368305657a6202944046", null ]
    ] ],
    [ "spa_node", "structspa__node.html", [
      [ "iface", "structspa__node.html#a898fcb8b2d37d7c42fd9c15d1f8c1ed7", null ]
    ] ],
    [ "spa_node_info", "structspa__node__info.html", [
      [ "max_input_ports", "structspa__node__info.html#a9f05f762157f2ae9db446937f19da173", null ],
      [ "max_output_ports", "structspa__node__info.html#a5c181a5c275e9a0c9ec82156a38f10a5", null ],
      [ "change_mask", "structspa__node__info.html#a985458f3b046fb6b7da0974ac08fe504", null ],
      [ "flags", "structspa__node__info.html#a248c6cf0005c3b29a3ceb1bbff232cd9", null ],
      [ "params", "structspa__node__info.html#a11fa9f260086bf624de400a80bf79219", null ],
      [ "n_params", "structspa__node__info.html#a41964dbf3b7ace8dd61b9f82d123b4d6", null ]
    ] ],
    [ "spa_port_info", "structspa__port__info.html", [
      [ "change_mask", "structspa__port__info.html#a81b330b23307447d948209a19d7a8aee", null ],
      [ "flags", "structspa__port__info.html#a099d9e63a823cd7705ca94b6bcda48d6", null ],
      [ "rate", "structspa__port__info.html#a0d1d7545d48016fa95629bf71b26c949", null ],
      [ "params", "structspa__port__info.html#a3f9832799f2903cdd623d71f958fbc5c", null ],
      [ "n_params", "structspa__port__info.html#ab6581ff27cf6d9cc624283ba6beed837", null ]
    ] ],
    [ "spa_result_node_error", "structspa__result__node__error.html", [
      [ "message", "structspa__result__node__error.html#a396020ed7279b7f3293cc2c2eec47485", null ]
    ] ],
    [ "spa_result_node_params", "structspa__result__node__params.html", [
      [ "id", "structspa__result__node__params.html#af68f44c87bc21f8f92bf59011004e78c", null ],
      [ "index", "structspa__result__node__params.html#abbef2c04c11cccaed96c8396db5b750f", null ],
      [ "next", "structspa__result__node__params.html#a9216b607f0684ca0fb5fe0a94c981dc9", null ],
      [ "param", "structspa__result__node__params.html#a16c5fa674ade3d0b6c6d120628b22497", null ]
    ] ],
    [ "spa_node_events", "structspa__node__events.html", [
      [ "version", "structspa__node__events.html#a37b6ed18688f456b4c4e9b157879414f", null ],
      [ "info", "structspa__node__events.html#a6950a2df9f758cbbe7651f9db3962bed", null ],
      [ "port_info", "structspa__node__events.html#a7915d7cc4ad14d41c0a0865798470429", null ],
      [ "result", "structspa__node__events.html#a64cd08176057e03e97babf5b36ecd7bf", null ],
      [ "event", "structspa__node__events.html#a4b3918e0034bb87549fe911028ca8741", null ]
    ] ],
    [ "spa_node_callbacks", "structspa__node__callbacks.html", [
      [ "version", "structspa__node__callbacks.html#a249a8d683dc8b92cdca1c0b9eed75d4d", null ],
      [ "ready", "structspa__node__callbacks.html#a2e4fa7f89e8c1d306d44569191c44311", null ],
      [ "reuse_buffer", "structspa__node__callbacks.html#a48ef28f7570e07dbfb45fdb247e02671", null ],
      [ "xrun", "structspa__node__callbacks.html#a597eb6e41252d8030e4d697b51406ad0", null ]
    ] ],
    [ "spa_node_methods", "structspa__node__methods.html", [
      [ "version", "structspa__node__methods.html#a9b95b184ba04c05972ca57c1ae16c346", null ],
      [ "add_listener", "structspa__node__methods.html#a2bb8310a8ab8273ac0f53b54c6b23223", null ],
      [ "set_callbacks", "structspa__node__methods.html#a8b0809c0e27afae1c9489bc5807e4cb7", null ],
      [ "sync", "structspa__node__methods.html#a3d23d14b7707fc2f3926a78d47dde720", null ],
      [ "enum_params", "structspa__node__methods.html#a788f398e8fa5e85f03ecb68602821204", null ],
      [ "set_param", "structspa__node__methods.html#a0ea59a508f6d40b5889c23940a036be6", null ],
      [ "set_io", "structspa__node__methods.html#ab76d1e119a213a4cd3e5a15fb783f829", null ],
      [ "send_command", "structspa__node__methods.html#accf0d924064ab5c9c1cdde7d0013232c", null ],
      [ "add_port", "structspa__node__methods.html#a7236a06df9ca3894d3164b7b0566cc54", null ],
      [ "remove_port", "structspa__node__methods.html#ac43bffc3912889ba2c35c8fe7c7142db", null ],
      [ "port_enum_params", "structspa__node__methods.html#a1f465eba7a1322ef153142227a68d43b", null ],
      [ "port_set_param", "structspa__node__methods.html#af04906b32eb2e2862e8e2e2b0ef71f0c", null ],
      [ "port_use_buffers", "structspa__node__methods.html#a2773ceced2814d3adec184fa5ad538d2", null ],
      [ "port_set_io", "structspa__node__methods.html#a2089aa56468969fa4e6e65d6c80dbd14", null ],
      [ "port_reuse_buffer", "structspa__node__methods.html#ab92b0dc3ae1a61ea5f291393e927de93", null ],
      [ "process", "structspa__node__methods.html#a2216e9265fde3d179e7bec8ae69baecc", null ]
    ] ],
    [ "spa_result_node_params_data", "structspa__result__node__params__data.html", [
      [ "builder", "structspa__result__node__params__data.html#ad11bffd25122b0ca2fef3ac7c360728c", null ],
      [ "data", "structspa__result__node__params__data.html#a8815a2e634f16dff3598e1a2fee6e469", null ]
    ] ],
    [ "SPA_NODE_COMMAND_ID", "group__spa__node.html#gad6554ded385c335b205111415b697db3", null ],
    [ "SPA_NODE_COMMAND_INIT", "group__spa__node.html#gaf2eed3ad98da6b63c5f28960c7c0af5b", null ],
    [ "SPA_NODE_EVENT_ID", "group__spa__node.html#ga2b5a11e5c59bbfe258928402b8ecc247", null ],
    [ "SPA_NODE_EVENT_INIT", "group__spa__node.html#ga7e7c8de3573cd643ee813c35ed254c35", null ],
    [ "SPA_STATUS_OK", "group__spa__node.html#ga4e7d5764a2a867b8194d6bc8bd9fec53", null ],
    [ "SPA_STATUS_NEED_DATA", "group__spa__node.html#ga7b9947653c8565b6d669dcc372f5a715", null ],
    [ "SPA_STATUS_HAVE_DATA", "group__spa__node.html#ga5169f21d468d09138ffed89d9a9a981b", null ],
    [ "SPA_STATUS_STOPPED", "group__spa__node.html#ga8d08c55314eaa527faf7f16a69e217c7", null ],
    [ "SPA_STATUS_DRAINED", "group__spa__node.html#ga5726a67531364cc9f2dba7aaf770b987", null ],
    [ "SPA_IO_BUFFERS_INIT", "group__spa__node.html#gae69edc800effe1c3f70e163611784a04", null ],
    [ "SPA_IO_MEMORY_INIT", "group__spa__node.html#ga6e56edfd21e88945c056adc8d17dd045", null ],
    [ "SPA_IO_CLOCK_FLAG_FREEWHEEL", "group__spa__node.html#ga421d271b07d7650f6b8018668ea771c7", null ],
    [ "SPA_IO_VIDEO_SIZE_VALID", "group__spa__node.html#ga50542c161ad0906f67b4be78ab2e71cd", null ],
    [ "SPA_IO_SEGMENT_BAR_FLAG_VALID", "group__spa__node.html#ga8a153a40c392f4d78b1dd45156b29f7c", null ],
    [ "SPA_IO_SEGMENT_VIDEO_FLAG_VALID", "group__spa__node.html#gac10fd7265f330c673c51a5719aaa6daa", null ],
    [ "SPA_IO_SEGMENT_VIDEO_FLAG_DROP_FRAME", "group__spa__node.html#ga4c330a3c64a59d32097c023ae48fa1f3", null ],
    [ "SPA_IO_SEGMENT_VIDEO_FLAG_PULL_DOWN", "group__spa__node.html#ga68edcebed9d71631dae2160bfac01d4a", null ],
    [ "SPA_IO_SEGMENT_VIDEO_FLAG_INTERLACED", "group__spa__node.html#ga6753ccddf224f13c6b7f68a20f4c500d", null ],
    [ "SPA_IO_SEGMENT_FLAG_LOOPING", "group__spa__node.html#ga7b8b213ba6b4950eb36c8fbea9fbebaf", null ],
    [ "SPA_IO_SEGMENT_FLAG_NO_POSITION", "group__spa__node.html#gaa6e5d57201d0e0c20773043a2a2989bf", null ],
    [ "SPA_IO_POSITION_MAX_SEGMENTS", "group__spa__node.html#ga9ac58e570992a64d125bd9f91985996f", null ],
    [ "SPA_IO_RATE_MATCH_FLAG_ACTIVE", "group__spa__node.html#ga920474a132a02e42e1a6269abffca423", null ],
    [ "SPA_KEY_NODE_NAME", "group__spa__node.html#ga7e9282d67981bd0d7cc34a8501b93ab2", null ],
    [ "SPA_KEY_NODE_DESCRIPTION", "group__spa__node.html#ga9d50627a49b34986d74524ca4238c228", null ],
    [ "SPA_KEY_NODE_LATENCY", "group__spa__node.html#ga8a3e4b89dbe6949139b02898cd5ba23a", null ],
    [ "SPA_KEY_NODE_MAX_LATENCY", "group__spa__node.html#gadcb55c17c2f80d36f159bc763fd309e7", null ],
    [ "SPA_KEY_NODE_DRIVER", "group__spa__node.html#gae05de298da37b1a5d644aa87cf2a5220", null ],
    [ "SPA_KEY_NODE_ALWAYS_PROCESS", "group__spa__node.html#ga735cc0ce0bd2e459658464a12605ea5c", null ],
    [ "SPA_KEY_NODE_PAUSE_ON_IDLE", "group__spa__node.html#ga6eba1ca5b408cb6913d6243a4869f2db", null ],
    [ "SPA_KEY_NODE_MONITOR", "group__spa__node.html#gafab7e244874674b26e9f688d5fec8591", null ],
    [ "SPA_KEY_PORT_NAME", "group__spa__node.html#gacda7725d41e954d4c5217ba95c447a69", null ],
    [ "SPA_KEY_PORT_ALIAS", "group__spa__node.html#ga9537506ba9e8517d27353be72d3e82b6", null ],
    [ "SPA_KEY_PORT_MONITOR", "group__spa__node.html#gae091e85290ec8a7578f48c2b5a73affe", null ],
    [ "SPA_KEY_PORT_IGNORE_LATENCY", "group__spa__node.html#gad0584e7a902df3de92b8c2be0aa2ff53", null ],
    [ "SPA_TYPE_INTERFACE_Node", "group__spa__node.html#ga5c57b4fb1d72db0725992bd91b858dd6", null ],
    [ "SPA_VERSION_NODE", "group__spa__node.html#ga856b63143b916ed8de520b98e46a18ce", null ],
    [ "SPA_NODE_CHANGE_MASK_FLAGS", "group__spa__node.html#ga6dc4d1bbfffa9f49d18168d5a8302459", null ],
    [ "SPA_NODE_CHANGE_MASK_PROPS", "group__spa__node.html#gad77bdd23db7c222a58280dcda2ed63ff", null ],
    [ "SPA_NODE_CHANGE_MASK_PARAMS", "group__spa__node.html#gaffb0b7df0a4786ad26e482f1372ba6a0", null ],
    [ "SPA_NODE_FLAG_RT", "group__spa__node.html#gaf0edf0bcb3ae5739c7a528dc99fab618", null ],
    [ "SPA_NODE_FLAG_IN_DYNAMIC_PORTS", "group__spa__node.html#ga32e97ff007afd7fa67a218705a93a4fa", null ],
    [ "SPA_NODE_FLAG_OUT_DYNAMIC_PORTS", "group__spa__node.html#ga42aef9e39e095e1a8ff2a18a650eebff", null ],
    [ "SPA_NODE_FLAG_IN_PORT_CONFIG", "group__spa__node.html#gafda72bd4c75a0c9111ad4106a15d2b3e", null ],
    [ "SPA_NODE_FLAG_OUT_PORT_CONFIG", "group__spa__node.html#gac91f473b71a0970ff818a390a734709f", null ],
    [ "SPA_NODE_FLAG_NEED_CONFIGURE", "group__spa__node.html#gaafd293e377199e19b1a9fd1b9fd96887", null ],
    [ "SPA_NODE_FLAG_ASYNC", "group__spa__node.html#ga6e48491bf4103fa2bc7e120e6b4ae9ef", null ],
    [ "SPA_NODE_INFO_INIT", "group__spa__node.html#ga8d06cc5e8185d6636941f519d5fdf595", null ],
    [ "SPA_PORT_CHANGE_MASK_FLAGS", "group__spa__node.html#ga07ad0379142c8c8e52b3cebf98a573ba", null ],
    [ "SPA_PORT_CHANGE_MASK_RATE", "group__spa__node.html#ga3e71660c556d55e8f71f14114156579d", null ],
    [ "SPA_PORT_CHANGE_MASK_PROPS", "group__spa__node.html#ga133da45e18e57716cf10424acd051d34", null ],
    [ "SPA_PORT_CHANGE_MASK_PARAMS", "group__spa__node.html#gacc3a19497d1bd883a046d8c431b08115", null ],
    [ "SPA_PORT_FLAG_REMOVABLE", "group__spa__node.html#ga33050ccc32ba7651ece70172b94bb026", null ],
    [ "SPA_PORT_FLAG_OPTIONAL", "group__spa__node.html#ga9dab3147e13bdac986d1755ae11f4de0", null ],
    [ "SPA_PORT_FLAG_CAN_ALLOC_BUFFERS", "group__spa__node.html#ga2f6a9687ad84fb6f7f7ffb4547c49b3e", null ],
    [ "SPA_PORT_FLAG_IN_PLACE", "group__spa__node.html#ga1494d415d780514b25eab3cbcbdd588d", null ],
    [ "SPA_PORT_FLAG_NO_REF", "group__spa__node.html#gaeee49d051bb080669113c6deeffa5d90", null ],
    [ "SPA_PORT_FLAG_LIVE", "group__spa__node.html#gacd1a9fa77a294261e70d48ec80ea2270", null ],
    [ "SPA_PORT_FLAG_PHYSICAL", "group__spa__node.html#ga279d6e7c36c46cc531079d442f4c87bc", null ],
    [ "SPA_PORT_FLAG_TERMINAL", "group__spa__node.html#ga7508decf7c6d0b240bf2521a0a2652a3", null ],
    [ "SPA_PORT_FLAG_DYNAMIC_DATA", "group__spa__node.html#ga5c50b8909b0b6bb8822b8072c97012c5", null ],
    [ "SPA_PORT_INFO_INIT", "group__spa__node.html#ga3d829ade49e9ca5053fc77ba57ea5b0f", null ],
    [ "SPA_RESULT_TYPE_NODE_ERROR", "group__spa__node.html#gac14d1a095e32e917a5be7867b50be1ef", null ],
    [ "SPA_RESULT_TYPE_NODE_PARAMS", "group__spa__node.html#gada8de413ca18ab054c45f9aba3503af9", null ],
    [ "SPA_NODE_EVENT_INFO", "group__spa__node.html#ga8868a325ff308e304b3831b852159a06", null ],
    [ "SPA_NODE_EVENT_PORT_INFO", "group__spa__node.html#gae881bab892a51d30cf3959fb03016b13", null ],
    [ "SPA_NODE_EVENT_RESULT", "group__spa__node.html#gaaec1fd867fc850187b9a238b41c2fc9e", null ],
    [ "SPA_NODE_EVENT_EVENT", "group__spa__node.html#ga2442fec0b32c8d89b723ca36b36a9a7d", null ],
    [ "SPA_NODE_EVENT_NUM", "group__spa__node.html#ga1d9234b4861d9524d2a4c34783e564da", null ],
    [ "SPA_VERSION_NODE_EVENTS", "group__spa__node.html#gade24550dee986c4a1279bfbaadce1636", null ],
    [ "SPA_NODE_CALLBACK_READY", "group__spa__node.html#ga1db34e09a392f01ce49cb99b8e57eacd", null ],
    [ "SPA_NODE_CALLBACK_REUSE_BUFFER", "group__spa__node.html#gad819a9a2cb2c5b53ae744c48568772f1", null ],
    [ "SPA_NODE_CALLBACK_XRUN", "group__spa__node.html#gab8988779b1aad632aa53dbf60c9c1433", null ],
    [ "SPA_NODE_CALLBACK_NUM", "group__spa__node.html#gad1ef7a91dc37b826328e4c304a58e79f", null ],
    [ "SPA_VERSION_NODE_CALLBACKS", "group__spa__node.html#ga5da30323ece5658c6b1cbcd745a1c85e", null ],
    [ "SPA_NODE_PARAM_FLAG_TEST_ONLY", "group__spa__node.html#ga9935dd7d98e7af74b297d3c937d1dd2b", null ],
    [ "SPA_NODE_PARAM_FLAG_FIXATE", "group__spa__node.html#gac8cf6bbbc679248b7b8c89fe0b265917", null ],
    [ "SPA_NODE_PARAM_FLAG_NEAREST", "group__spa__node.html#ga1af3d4b870d8b10da42a46884ef28df3", null ],
    [ "SPA_NODE_BUFFERS_FLAG_ALLOC", "group__spa__node.html#gaed43186ba554d0253f721dda55ffe84d", null ],
    [ "SPA_NODE_METHOD_ADD_LISTENER", "group__spa__node.html#ga850b3e7809349b7b796567f3b3f86fa6", null ],
    [ "SPA_NODE_METHOD_SET_CALLBACKS", "group__spa__node.html#gaa8d97c3e1c31a106b047ddc2edb7c2b6", null ],
    [ "SPA_NODE_METHOD_SYNC", "group__spa__node.html#gadb0d4466139648f1937c0ea07b150e19", null ],
    [ "SPA_NODE_METHOD_ENUM_PARAMS", "group__spa__node.html#ga2cbf3c2d7235989a185d7c01e35c9fdf", null ],
    [ "SPA_NODE_METHOD_SET_PARAM", "group__spa__node.html#ga3fbe0949f4a9985f7b4ae50959e1a225", null ],
    [ "SPA_NODE_METHOD_SET_IO", "group__spa__node.html#gabaf3555141b333cb04f4a9d124bb5d0b", null ],
    [ "SPA_NODE_METHOD_SEND_COMMAND", "group__spa__node.html#ga784ec374e7b19204bec41fffca6a1abd", null ],
    [ "SPA_NODE_METHOD_ADD_PORT", "group__spa__node.html#ga53861878ba33e9885e221ceb9a3b2d61", null ],
    [ "SPA_NODE_METHOD_REMOVE_PORT", "group__spa__node.html#gad3d0d597b9c901a69e6b9fd647594c76", null ],
    [ "SPA_NODE_METHOD_PORT_ENUM_PARAMS", "group__spa__node.html#ga4057156d1eaf9f13cab72a187735ad65", null ],
    [ "SPA_NODE_METHOD_PORT_SET_PARAM", "group__spa__node.html#ga7345b7229cf2cf9e60cf142cd6c8c536", null ],
    [ "SPA_NODE_METHOD_PORT_USE_BUFFERS", "group__spa__node.html#gad38cbd64d76d204d1448fa108ff77053", null ],
    [ "SPA_NODE_METHOD_PORT_SET_IO", "group__spa__node.html#ga800784853f7d925567d9aaf666ff1a10", null ],
    [ "SPA_NODE_METHOD_PORT_REUSE_BUFFER", "group__spa__node.html#ga81ae3a5666e6a8b3b8236f8ff7749ea3", null ],
    [ "SPA_NODE_METHOD_PROCESS", "group__spa__node.html#ga02fe74bd20e4af4c6b51a22dfd7aee85", null ],
    [ "SPA_NODE_METHOD_NUM", "group__spa__node.html#gaf9f1bf717bf713b7c019934218c05a5c", null ],
    [ "SPA_VERSION_NODE_METHODS", "group__spa__node.html#gaee7d45b6819789bde3de86d9be592a3a", null ],
    [ "spa_node_method", "group__spa__node.html#gaf6acc77e506b002f4af0ecd03e29c6ff", null ],
    [ "spa_node_method_fast", "group__spa__node.html#ga3ad11e9ae12a8d68f35fa708e0fca6d5", null ],
    [ "spa_node_add_listener", "group__spa__node.html#ga594ac9d44ca70f66f42b9deb408f0e51", null ],
    [ "spa_node_set_callbacks", "group__spa__node.html#gafc6f880a7906ab6ad837b753b6c2de05", null ],
    [ "spa_node_sync", "group__spa__node.html#gabb7d0304d2f9952bcf6b95041573c2a4", null ],
    [ "spa_node_enum_params", "group__spa__node.html#gad62e2c5acaf8499bd307e16477ba1a97", null ],
    [ "spa_node_set_param", "group__spa__node.html#gaa1b58b1433ccdb1e22550ed44981e1d4", null ],
    [ "spa_node_set_io", "group__spa__node.html#ga2e8fde2df4533ca4b53da3a44d7bf233", null ],
    [ "spa_node_send_command", "group__spa__node.html#gad8a56491e1cb021d5a6f168a538a6ae5", null ],
    [ "spa_node_add_port", "group__spa__node.html#ga966406405be3cfd4d9e2e419d93aad0c", null ],
    [ "spa_node_remove_port", "group__spa__node.html#ga1c48d90a1e89b65654a85da59ae267dd", null ],
    [ "spa_node_port_enum_params", "group__spa__node.html#ga5d06b1bee8257f3c26d745018435bfb3", null ],
    [ "spa_node_port_set_param", "group__spa__node.html#gaa26c9e47c911179baa62f25a335076b0", null ],
    [ "spa_node_port_use_buffers", "group__spa__node.html#gaf7f6bdf00d83c8aaa4cb13c983ff3ff6", null ],
    [ "spa_node_port_set_io", "group__spa__node.html#ga8c921a18a870cfc3163861b4fb7df6b1", null ],
    [ "spa_node_port_reuse_buffer", "group__spa__node.html#ga78928697897c91bedd278b7ab72e8380", null ],
    [ "spa_node_port_reuse_buffer_fast", "group__spa__node.html#ga9daa5c8e89a00eb95ba4571693cd1694", null ],
    [ "spa_node_process", "group__spa__node.html#ga9d4577c9ba65dce198293c8b777ae874", null ],
    [ "spa_node_process_fast", "group__spa__node.html#ga06f7bd68dcac9beb014db111b4e64b33", null ],
    [ "SPA_TYPE_INFO_IO", "group__spa__node.html#ga307753db51558b08071e4f2822228672", null ],
    [ "SPA_TYPE_INFO_IO_BASE", "group__spa__node.html#gaa8e30ee6ab74de00871c610bad6eeaf8", null ],
    [ "SPA_TYPE_INFO_NodeEvent", "group__spa__node.html#ga5716dde5392df4653ff81188fc6ed47e", null ],
    [ "SPA_TYPE_INFO_NODE_EVENT_BASE", "group__spa__node.html#ga8c831fdc677c869f88cc13d81c317939", null ],
    [ "SPA_TYPE_INFO_NodeCommand", "group__spa__node.html#ga698610695f5a9a80459847fa95a68621", null ],
    [ "SPA_TYPE_INFO_NODE_COMMAND_BASE", "group__spa__node.html#gac0b1456e0915963066c9a3cae842c9e1", null ],
    [ "spa_node_emit", "group__spa__node.html#ga1dfd6ca0baebeb94f35fe58fe19b81d9", null ],
    [ "spa_node_emit_info", "group__spa__node.html#ga030c84ccc7f2f1190f1ef3b246756121", null ],
    [ "spa_node_emit_port_info", "group__spa__node.html#ga2dbb6c19156dd04a8b53bd08f30ae460", null ],
    [ "spa_node_emit_result", "group__spa__node.html#gae30aeb4988d0b38916a8e40fe3620b65", null ],
    [ "spa_node_emit_event", "group__spa__node.html#gad744ab5bf6a56885dd8f283fd28b911c", null ],
    [ "spa_node_call", "group__spa__node.html#ga7d7d4aa2fe72df4d60de993aabb8f70c", null ],
    [ "spa_node_call_ready", "group__spa__node.html#gab23963cc540a69dc6c7f482e655d4b70", null ],
    [ "spa_node_call_reuse_buffer", "group__spa__node.html#gaf4fd1fa9983cfe26d6d3a08bc34c8230", null ],
    [ "spa_node_call_xrun", "group__spa__node.html#gae06e2ee893ca6c894411795b564161c6", null ],
    [ "spa_node_command", "group__spa__node.html#gae5da16ead1c0ebe3f41d5b3ee27d4f60", [
      [ "SPA_NODE_COMMAND_Suspend", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a481c2cf7b711ffb126298fc54d3ebd50", null ],
      [ "SPA_NODE_COMMAND_Pause", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a54ac1f6dcfa9f84def2ebe656f81f36b", null ],
      [ "SPA_NODE_COMMAND_Start", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60ac876b55c87a615cc06929716d63bb15b", null ],
      [ "SPA_NODE_COMMAND_Enable", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a45600fb65016e27c151e1e97c85cacd3", null ],
      [ "SPA_NODE_COMMAND_Disable", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a0fb46fa2ac58518cac077f0acab7ed8f", null ],
      [ "SPA_NODE_COMMAND_Flush", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a37c85cb1fa62997d4c60096d2fa4e0ea", null ],
      [ "SPA_NODE_COMMAND_Drain", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a5e6e0fd9ebc6779f4ebc19226ce735fe", null ],
      [ "SPA_NODE_COMMAND_Marker", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a64bf8f88cb260787a8b57ed830660469", null ],
      [ "SPA_NODE_COMMAND_ParamBegin", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60ab4505935610169df9fabbfdcdf473812", null ],
      [ "SPA_NODE_COMMAND_ParamEnd", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60acdab0f31c63fe3b66444558fed7440bd", null ],
      [ "SPA_NODE_COMMAND_RequestProcess", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a0c040b68838602058673395761713bdc", null ]
    ] ],
    [ "spa_node_event", "group__spa__node.html#gadcbf11755fca00d5a654a79ee80fdb81", [
      [ "SPA_NODE_EVENT_Error", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81a8390ac4315ffa1d12f262266becf5812", null ],
      [ "SPA_NODE_EVENT_Buffering", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81ad57a942adfadd9bb655418127a644b42", null ],
      [ "SPA_NODE_EVENT_RequestRefresh", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81af8d56477659a6f8817cf173004c94955", null ],
      [ "SPA_NODE_EVENT_RequestProcess", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81a53f96b85c26097dc07ed3b6e137b161f", null ]
    ] ],
    [ "spa_event_node", "group__spa__node.html#gae111175d27c9aa0b465b826bc55c9be1", [
      [ "SPA_EVENT_NODE_START", "group__spa__node.html#ggae111175d27c9aa0b465b826bc55c9be1ad73df09f7d608ee04395ad8162417fcd", null ]
    ] ],
    [ "spa_io_type", "group__spa__node.html#ga89c01db6072aa9fd9ca5ac4dee9b6716", [
      [ "SPA_IO_Invalid", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716ac69bf5ac901b028e6f303e5f1c79fab4", null ],
      [ "SPA_IO_Buffers", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716add933078af870e2fe9852b209ef70931", null ],
      [ "SPA_IO_Range", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716ac5afde929aa9030bffd46543b02fc0c1", null ],
      [ "SPA_IO_Clock", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716a6a15e30ee2269b129ef5acb0e6671d41", null ],
      [ "SPA_IO_Latency", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716ab9fcd93a987a6206804df617ff988a3e", null ],
      [ "SPA_IO_Control", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716a96ec506b28f49b44b1c19802c15c618c", null ],
      [ "SPA_IO_Notify", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716a3aefc21098cbdc2b55cbbdc32629b2de", null ],
      [ "SPA_IO_Position", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716ad26051f31e62903ba07f33db72a3941e", null ],
      [ "SPA_IO_RateMatch", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716aed9fe718c56e44e01e02e6e8b31567d2", null ],
      [ "SPA_IO_Memory", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716a41fcd276edf87cfe8eea522109de2f20", null ]
    ] ],
    [ "spa_io_position_state", "group__spa__node.html#ga12aed5ed2a6ecb69734aa3eb7da4056b", [
      [ "SPA_IO_POSITION_STATE_STOPPED", "group__spa__node.html#gga12aed5ed2a6ecb69734aa3eb7da4056ba38a0f9a63830ad342b24e09879621165", null ],
      [ "SPA_IO_POSITION_STATE_STARTING", "group__spa__node.html#gga12aed5ed2a6ecb69734aa3eb7da4056ba938768f7da496bf7d953372b247d5030", null ],
      [ "SPA_IO_POSITION_STATE_RUNNING", "group__spa__node.html#gga12aed5ed2a6ecb69734aa3eb7da4056ba2dca266818c242b100929746f01af7ff", null ]
    ] ],
    [ "spa_result_func_node_params", "group__spa__node.html#ga220a50a12909fbe19a2738fa17658235", null ],
    [ "spa_node_enum_params_sync", "group__spa__node.html#ga38d51bd4e324b9fa9f1289c8c41ee611", null ],
    [ "spa_node_port_enum_params_sync", "group__spa__node.html#gaccf324882da5942ac8622af7760bff4d", null ],
    [ "spa_type_io", "group__spa__node.html#gad296f95f21eece76aa6838734f1453b3", null ],
    [ "spa_type_node_event_id", "group__spa__node.html#gab13c0d45af673773c71f4a370384f4ec", null ],
    [ "spa_type_node_event", "group__spa__node.html#ga90709238b87febc59d242d7fdd881f3c", null ],
    [ "spa_type_node_command_id", "group__spa__node.html#gaabb47ce8e96ed14b594c3fe6fd5a56ca", null ],
    [ "spa_type_node_command", "group__spa__node.html#ga2c2f873a1a347f49cb30f5d692d18721", null ]
];